/* Autogenerated: 'src/ExtractionOCaml/unsaturated_solinas' --lang Java --cmovznz-by-mul --widen-carry --widen-bytes --internal-static --package-name fiat_crypto --class-case UpperCamelCase --no-field-element-typedefs P521 32 '(auto)' '2^521 - 1' carry_mul carry_square carry add sub opp selectznz to_bytes from_bytes relax */
/* curve description: P521 */
/* machine_wordsize = 32 (from "32") */
/* requested operations: carry_mul, carry_square, carry, add, sub, opp, selectznz, to_bytes, from_bytes, relax */
/* n = 19 (from "(auto)") */
/* s-c = 2^521 - [(1, 1)] (from "2^521 - 1") */
/* tight_bounds_multiplier = 1 (from "") */
/*  */
/* Computed values: */
/*   carry_chain = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 0, 1] */
/*   eval z = z[0] + (z[1] << 28) + (z[2] << 55) + (z[3] << 83) + (z[4] << 110) + (z[5] << 138) + (z[6] << 165) + (z[7] << 192) + (z[8] << 220) + (z[9] << 247) + (z[10] << 0x113) + (z[11] << 0x12e) + (z[12] << 0x14a) + (z[13] << 0x165) + (z[14] << 0x180) + (z[15] << 0x19c) + (z[16] << 0x1b7) + (z[17] << 0x1d3) + (z[18] << 0x1ee) */
/*   bytes_eval z = z[0] + (z[1] << 8) + (z[2] << 16) + (z[3] << 24) + (z[4] << 32) + (z[5] << 40) + (z[6] << 48) + (z[7] << 56) + (z[8] << 64) + (z[9] << 72) + (z[10] << 80) + (z[11] << 88) + (z[12] << 96) + (z[13] << 104) + (z[14] << 112) + (z[15] << 120) + (z[16] << 128) + (z[17] << 136) + (z[18] << 144) + (z[19] << 152) + (z[20] << 160) + (z[21] << 168) + (z[22] << 176) + (z[23] << 184) + (z[24] << 192) + (z[25] << 200) + (z[26] << 208) + (z[27] << 216) + (z[28] << 224) + (z[29] << 232) + (z[30] << 240) + (z[31] << 248) + (z[32] << 256) + (z[33] << 0x108) + (z[34] << 0x110) + (z[35] << 0x118) + (z[36] << 0x120) + (z[37] << 0x128) + (z[38] << 0x130) + (z[39] << 0x138) + (z[40] << 0x140) + (z[41] << 0x148) + (z[42] << 0x150) + (z[43] << 0x158) + (z[44] << 0x160) + (z[45] << 0x168) + (z[46] << 0x170) + (z[47] << 0x178) + (z[48] << 0x180) + (z[49] << 0x188) + (z[50] << 0x190) + (z[51] << 0x198) + (z[52] << 0x1a0) + (z[53] << 0x1a8) + (z[54] << 0x1b0) + (z[55] << 0x1b8) + (z[56] << 0x1c0) + (z[57] << 0x1c8) + (z[58] << 0x1d0) + (z[59] << 0x1d8) + (z[60] << 0x1e0) + (z[61] << 0x1e8) + (z[62] << 0x1f0) + (z[63] << 0x1f8) + (z[64] << 2^9) + (z[65] << 0x208) */
/*   balance = [0x1ffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0x1ffffffe, 0xffffffe, 0xffffffe] */

package fiat_crypto;

public final class FiatP521 {

static class Box<T> {
  private T value;
  public Box(T value) { this.value = value; }
  public void set(T value) { this.value = value; }
  public T get() { return this.value; }
}



/**
 * The function fiat_P521_addcarryx_u28 is an addition with carry. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (arg1 + arg2 + arg3) mod 2^28 <p>
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^28⌋ <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [0x0 ~&gt; 0xfffffff] <p>
 *   arg3: [0x0 ~&gt; 0xfffffff] <p>
 * Output Bounds: <p>
 *   out1: [0x0 ~&gt; 0xfffffff] <p>
 *   out2: [0x0 ~&gt; 0x1] <p>
 */
static void fiat_P521_addcarryx_u28(Box<Integer> out1, Box<Integer> out2, int arg1, int arg2, int arg3) {
  int x1 = ((arg1 + arg2) + arg3);
  int x2 = (x1 & 0xfffffff);
  int x3 = (x1 >>> 28);
  out1.set(x2);
  out2.set(x3);
}

/**
 * The function fiat_P521_subborrowx_u28 is a subtraction with borrow. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^28 <p>
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^28⌋ <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [0x0 ~&gt; 0xfffffff] <p>
 *   arg3: [0x0 ~&gt; 0xfffffff] <p>
 * Output Bounds: <p>
 *   out1: [0x0 ~&gt; 0xfffffff] <p>
 *   out2: [0x0 ~&gt; 0x1] <p>
 */
static void fiat_P521_subborrowx_u28(Box<Integer> out1, Box<Integer> out2, int arg1, int arg2, int arg3) {
  int x1 = (((int) Integer.toUnsignedLong(((Number) (arg2)).intValue()) - (int) Integer.toUnsignedLong(((Number) (arg1)).intValue())) - (int) Integer.toUnsignedLong(((Number) (arg3)).intValue()));
  int x2 = (x1 >>> 28);
  int x3 = ((int) Integer.toUnsignedLong(((Number) (x1)).intValue()) & 0xfffffff);
  out1.set(x3);
  out2.set(((int) Integer.toUnsignedLong(((Number) (0x0)).intValue()) - (int) Integer.toUnsignedLong(((Number) (x2)).intValue())));
}

/**
 * The function fiat_P521_addcarryx_u27 is an addition with carry. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (arg1 + arg2 + arg3) mod 2^27 <p>
 *   out2 = ⌊(arg1 + arg2 + arg3) / 2^27⌋ <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [0x0 ~&gt; 0x7ffffff] <p>
 *   arg3: [0x0 ~&gt; 0x7ffffff] <p>
 * Output Bounds: <p>
 *   out1: [0x0 ~&gt; 0x7ffffff] <p>
 *   out2: [0x0 ~&gt; 0x1] <p>
 */
static void fiat_P521_addcarryx_u27(Box<Integer> out1, Box<Integer> out2, int arg1, int arg2, int arg3) {
  int x1 = ((arg1 + arg2) + arg3);
  int x2 = (x1 & 0x7ffffff);
  int x3 = (x1 >>> 27);
  out1.set(x2);
  out2.set(x3);
}

/**
 * The function fiat_P521_subborrowx_u27 is a subtraction with borrow. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (-arg1 + arg2 + -arg3) mod 2^27 <p>
 *   out2 = -⌊(-arg1 + arg2 + -arg3) / 2^27⌋ <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [0x0 ~&gt; 0x7ffffff] <p>
 *   arg3: [0x0 ~&gt; 0x7ffffff] <p>
 * Output Bounds: <p>
 *   out1: [0x0 ~&gt; 0x7ffffff] <p>
 *   out2: [0x0 ~&gt; 0x1] <p>
 */
static void fiat_P521_subborrowx_u27(Box<Integer> out1, Box<Integer> out2, int arg1, int arg2, int arg3) {
  int x1 = (((int) Integer.toUnsignedLong(((Number) (arg2)).intValue()) - (int) Integer.toUnsignedLong(((Number) (arg1)).intValue())) - (int) Integer.toUnsignedLong(((Number) (arg3)).intValue()));
  int x2 = (x1 >>> 27);
  int x3 = ((int) Integer.toUnsignedLong(((Number) (x1)).intValue()) & 0x7ffffff);
  out1.set(x3);
  out2.set(((int) Integer.toUnsignedLong(((Number) (0x0)).intValue()) - (int) Integer.toUnsignedLong(((Number) (x2)).intValue())));
}

/**
 * The function fiat_P521_cmovznz_u32 is a single-word conditional move. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (if arg1 = 0 then arg2 else arg3) <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [0x0 ~&gt; 0xffffffff] <p>
 *   arg3: [0x0 ~&gt; 0xffffffff] <p>
 * Output Bounds: <p>
 *   out1: [0x0 ~&gt; 0xffffffff] <p>
 */
static void fiat_P521_cmovznz_u32(Box<Integer> out1, int arg1, int arg2, int arg3) {
  int x1 = (arg1 * 0xffffffff);
  int x2 = ((x1 & arg3) | ((~x1) & arg2));
  out1.set(x2);
}

/**
 * The function fiat_P521_carry_mul multiplies two field elements and reduces the result. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = (eval arg1 * eval arg2) mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 *   arg2: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 */
public static void fiat_P521_carry_mul(int[] out1, final int[] arg1, final int[] arg2) {
  long x1 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x2 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x3 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x4 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x5 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x6 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x7 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x8 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x9 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x10 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x11 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x12 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x13 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x14 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x15 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x16 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x17 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x18 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x19 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x20 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x21 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[16]) * 0x2))).intValue()));
  long x22 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x23 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x24 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x25 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x26 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x27 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x28 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[9]) * 0x2))).intValue()));
  long x29 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x30 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x31 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x32 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x33 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x34 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x35 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[2]) * 0x2))).intValue()));
  long x36 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x37 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x38 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x39 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x40 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x41 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x42 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x43 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x44 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x45 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x46 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x47 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x48 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x49 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x50 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x51 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x52 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x53 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x54 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x55 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x56 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x57 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x58 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x59 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x60 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x61 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x62 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x63 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x64 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x65 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x66 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x67 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x68 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[17]))).intValue()));
  long x69 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x70 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x71 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x72 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x73 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x74 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x75 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[10]))).intValue()));
  long x76 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x77 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x78 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x79 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x80 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x81 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x82 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x83 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x84 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x85 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x86 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x87 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x88 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x89 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x90 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x91 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x92 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x93 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x94 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x95 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x96 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[16]) * 0x2))).intValue()));
  long x97 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x98 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[14]) * 0x2))).intValue()));
  long x99 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x100 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x101 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x102 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x103 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[9]) * 0x2))).intValue()));
  long x104 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x105 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[7]) * 0x2))).intValue()));
  long x106 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x107 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x108 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x109 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x110 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x111 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x112 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x113 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x114 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x115 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x116 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x117 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x118 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x119 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[16]) * 0x2))).intValue()));
  long x120 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x121 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x122 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x123 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x124 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x125 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x126 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[9]) * 0x2))).intValue()));
  long x127 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x128 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x129 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x130 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x131 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x132 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x133 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x134 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x135 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x136 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x137 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x138 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x139 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x140 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x141 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x142 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x143 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x144 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x145 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[17]))).intValue()));
  long x146 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x147 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x148 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x149 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x150 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x151 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x152 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x153 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x154 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x155 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x156 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x157 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x158 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x159 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[16]) * 0x2))).intValue()));
  long x160 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x161 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[14]) * 0x2))).intValue()));
  long x162 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x163 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x164 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x165 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x166 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x167 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x168 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[16]) * 0x2))).intValue()));
  long x169 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x170 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x171 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[18]) * 0x2))).intValue()));
  long x172 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x173 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x174 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x175 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x176 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x177 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x178 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x179 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x180 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x181 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x182 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x183 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[3]))).intValue()));
  long x184 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x185 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x186 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x187 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x188 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x189 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x190 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x191 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x192 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x193 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x194 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x195 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x196 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x197 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[2]) * 0x2))).intValue()));
  long x198 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x199 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x200 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x201 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x202 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x203 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x204 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x205 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x206 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x207 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x208 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x209 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x210 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x211 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x212 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x213 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x214 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x215 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x216 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x217 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x218 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x219 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x220 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x221 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x222 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x223 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[3]))).intValue()));
  long x224 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x225 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x226 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x227 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x228 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x229 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x230 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x231 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x232 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x233 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x234 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x235 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x236 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x237 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x238 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x239 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[10]))).intValue()));
  long x240 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x241 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x242 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x243 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x244 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[5]))).intValue()));
  long x245 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x246 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[3]))).intValue()));
  long x247 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x248 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x249 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x250 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x251 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x252 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x253 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x254 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x255 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x256 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x257 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x258 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x259 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x260 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x261 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x262 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x263 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x264 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x265 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x266 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x267 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[9]) * 0x2))).intValue()));
  long x268 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x269 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x270 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x271 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x272 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x273 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x274 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[2]) * 0x2))).intValue()));
  long x275 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x276 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x277 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x278 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x279 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x280 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x281 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x282 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x283 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x284 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x285 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x286 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x287 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x288 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x289 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x290 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x291 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x292 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x293 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x294 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x295 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x296 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[11]) * 0x2))).intValue()));
  long x297 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x298 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x299 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x300 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x301 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x302 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x303 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[4]) * 0x2))).intValue()));
  long x304 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x305 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x306 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x307 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x308 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x309 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x310 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x311 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x312 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x313 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x314 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[10]))).intValue()));
  long x315 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x316 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x317 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x318 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x319 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x320 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x321 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[3]))).intValue()));
  long x322 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x323 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x324 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x325 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[17]) * 0x2))).intValue()));
  long x326 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x327 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[15]) * 0x2))).intValue()));
  long x328 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x329 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[13]) * 0x2))).intValue()));
  long x330 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[12]) * 0x2))).intValue()));
  long x331 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x332 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[10]) * 0x2))).intValue()));
  long x333 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x334 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[8]) * 0x2))).intValue()));
  long x335 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x336 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[6]) * 0x2))).intValue()));
  long x337 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[5]) * 0x2))).intValue()));
  long x338 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x339 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[3]) * 0x2))).intValue()));
  long x340 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x341 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg2[1]) * 0x2))).intValue()));
  long x342 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x343 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[18]))).intValue()));
  long x344 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[17]))).intValue()));
  long x345 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[16]))).intValue()));
  long x346 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[15]))).intValue()));
  long x347 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[14]))).intValue()));
  long x348 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[13]))).intValue()));
  long x349 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[12]))).intValue()));
  long x350 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[11]))).intValue()));
  long x351 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[10]))).intValue()));
  long x352 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[9]))).intValue()));
  long x353 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[8]))).intValue()));
  long x354 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[7]))).intValue()));
  long x355 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[6]))).intValue()));
  long x356 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[5]))).intValue()));
  long x357 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[4]))).intValue()));
  long x358 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[3]))).intValue()));
  long x359 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[2]))).intValue()));
  long x360 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[1]))).intValue()));
  long x361 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg2[0]))).intValue()));
  long x362 = (x361 + (x171 + (x170 + (x168 + (x165 + (x161 + (x156 + (x150 + (x143 + (x135 + (x126 + (x116 + (x105 + (x93 + (x80 + (x66 + (x51 + (x35 + x18))))))))))))))))));
  long x363 = (x362 >>> 28);
  int x364 = ((int) Integer.toUnsignedLong(((Number) (x362)).intValue()) & 0xfffffff);
  long x365 = (x343 + (x325 + (x308 + (x292 + (x277 + (x263 + (x250 + (x238 + (x227 + (x217 + (x208 + (x200 + (x193 + (x187 + (x182 + (x178 + (x175 + (x173 + x172))))))))))))))))));
  long x366 = (x344 + (x326 + (x309 + (x293 + (x278 + (x264 + (x251 + (x239 + (x228 + (x218 + (x209 + (x201 + (x194 + (x188 + (x183 + (x179 + (x176 + (x174 + x1))))))))))))))))));
  long x367 = (x345 + (x327 + (x310 + (x294 + (x279 + (x265 + (x252 + (x240 + (x229 + (x219 + (x210 + (x202 + (x195 + (x189 + (x184 + (x180 + (x177 + (x19 + x2))))))))))))))))));
  long x368 = (x346 + (x328 + (x311 + (x295 + (x280 + (x266 + (x253 + (x241 + (x230 + (x220 + (x211 + (x203 + (x196 + (x190 + (x185 + (x181 + (x36 + (x20 + x3))))))))))))))))));
  long x369 = (x347 + (x329 + (x312 + (x296 + (x281 + (x267 + (x254 + (x242 + (x231 + (x221 + (x212 + (x204 + (x197 + (x191 + (x186 + (x52 + (x37 + (x21 + x4))))))))))))))))));
  long x370 = (x348 + (x330 + (x313 + (x297 + (x282 + (x268 + (x255 + (x243 + (x232 + (x222 + (x213 + (x205 + (x198 + (x192 + (x67 + (x53 + (x38 + (x22 + x5))))))))))))))))));
  long x371 = (x349 + (x331 + (x314 + (x298 + (x283 + (x269 + (x256 + (x244 + (x233 + (x223 + (x214 + (x206 + (x199 + (x81 + (x68 + (x54 + (x39 + (x23 + x6))))))))))))))))));
  long x372 = (x350 + (x332 + (x315 + (x299 + (x284 + (x270 + (x257 + (x245 + (x234 + (x224 + (x215 + (x207 + (x94 + (x82 + (x69 + (x55 + (x40 + (x24 + x7))))))))))))))))));
  long x373 = (x351 + (x333 + (x316 + (x300 + (x285 + (x271 + (x258 + (x246 + (x235 + (x225 + (x216 + (x106 + (x95 + (x83 + (x70 + (x56 + (x41 + (x25 + x8))))))))))))))))));
  long x374 = (x352 + (x334 + (x317 + (x301 + (x286 + (x272 + (x259 + (x247 + (x236 + (x226 + (x117 + (x107 + (x96 + (x84 + (x71 + (x57 + (x42 + (x26 + x9))))))))))))))))));
  long x375 = (x353 + (x335 + (x318 + (x302 + (x287 + (x273 + (x260 + (x248 + (x237 + (x127 + (x118 + (x108 + (x97 + (x85 + (x72 + (x58 + (x43 + (x27 + x10))))))))))))))))));
  long x376 = (x354 + (x336 + (x319 + (x303 + (x288 + (x274 + (x261 + (x249 + (x136 + (x128 + (x119 + (x109 + (x98 + (x86 + (x73 + (x59 + (x44 + (x28 + x11))))))))))))))))));
  long x377 = (x355 + (x337 + (x320 + (x304 + (x289 + (x275 + (x262 + (x144 + (x137 + (x129 + (x120 + (x110 + (x99 + (x87 + (x74 + (x60 + (x45 + (x29 + x12))))))))))))))))));
  long x378 = (x356 + (x338 + (x321 + (x305 + (x290 + (x276 + (x151 + (x145 + (x138 + (x130 + (x121 + (x111 + (x100 + (x88 + (x75 + (x61 + (x46 + (x30 + x13))))))))))))))))));
  long x379 = (x357 + (x339 + (x322 + (x306 + (x291 + (x157 + (x152 + (x146 + (x139 + (x131 + (x122 + (x112 + (x101 + (x89 + (x76 + (x62 + (x47 + (x31 + x14))))))))))))))))));
  long x380 = (x358 + (x340 + (x323 + (x307 + (x162 + (x158 + (x153 + (x147 + (x140 + (x132 + (x123 + (x113 + (x102 + (x90 + (x77 + (x63 + (x48 + (x32 + x15))))))))))))))))));
  long x381 = (x359 + (x341 + (x324 + (x166 + (x163 + (x159 + (x154 + (x148 + (x141 + (x133 + (x124 + (x114 + (x103 + (x91 + (x78 + (x64 + (x49 + (x33 + x16))))))))))))))))));
  long x382 = (x360 + (x342 + (x169 + (x167 + (x164 + (x160 + (x155 + (x149 + (x142 + (x134 + (x125 + (x115 + (x104 + (x92 + (x79 + (x65 + (x50 + (x34 + x17))))))))))))))))));
  long x383 = (x363 + x382);
  long x384 = (x383 >>> 27);
  int x385 = ((int) Integer.toUnsignedLong(((Number) (x383)).intValue()) & 0x7ffffff);
  long x386 = (x384 + x381);
  long x387 = (x386 >>> 28);
  int x388 = ((int) Integer.toUnsignedLong(((Number) (x386)).intValue()) & 0xfffffff);
  long x389 = (x387 + x380);
  long x390 = (x389 >>> 27);
  int x391 = ((int) Integer.toUnsignedLong(((Number) (x389)).intValue()) & 0x7ffffff);
  long x392 = (x390 + x379);
  long x393 = (x392 >>> 28);
  int x394 = ((int) Integer.toUnsignedLong(((Number) (x392)).intValue()) & 0xfffffff);
  long x395 = (x393 + x378);
  long x396 = (x395 >>> 27);
  int x397 = ((int) Integer.toUnsignedLong(((Number) (x395)).intValue()) & 0x7ffffff);
  long x398 = (x396 + x377);
  long x399 = (x398 >>> 27);
  int x400 = ((int) Integer.toUnsignedLong(((Number) (x398)).intValue()) & 0x7ffffff);
  long x401 = (x399 + x376);
  long x402 = (x401 >>> 28);
  int x403 = ((int) Integer.toUnsignedLong(((Number) (x401)).intValue()) & 0xfffffff);
  long x404 = (x402 + x375);
  long x405 = (x404 >>> 27);
  int x406 = ((int) Integer.toUnsignedLong(((Number) (x404)).intValue()) & 0x7ffffff);
  long x407 = (x405 + x374);
  long x408 = (x407 >>> 28);
  int x409 = ((int) Integer.toUnsignedLong(((Number) (x407)).intValue()) & 0xfffffff);
  long x410 = (x408 + x373);
  long x411 = (x410 >>> 27);
  int x412 = ((int) Integer.toUnsignedLong(((Number) (x410)).intValue()) & 0x7ffffff);
  long x413 = (x411 + x372);
  long x414 = (x413 >>> 28);
  int x415 = ((int) Integer.toUnsignedLong(((Number) (x413)).intValue()) & 0xfffffff);
  long x416 = (x414 + x371);
  long x417 = (x416 >>> 27);
  int x418 = ((int) Integer.toUnsignedLong(((Number) (x416)).intValue()) & 0x7ffffff);
  long x419 = (x417 + x370);
  long x420 = (x419 >>> 27);
  int x421 = ((int) Integer.toUnsignedLong(((Number) (x419)).intValue()) & 0x7ffffff);
  long x422 = (x420 + x369);
  long x423 = (x422 >>> 28);
  int x424 = ((int) Integer.toUnsignedLong(((Number) (x422)).intValue()) & 0xfffffff);
  long x425 = (x423 + x368);
  long x426 = (x425 >>> 27);
  int x427 = ((int) Integer.toUnsignedLong(((Number) (x425)).intValue()) & 0x7ffffff);
  long x428 = (x426 + x367);
  long x429 = (x428 >>> 28);
  int x430 = ((int) Integer.toUnsignedLong(((Number) (x428)).intValue()) & 0xfffffff);
  long x431 = (x429 + x366);
  long x432 = (x431 >>> 27);
  int x433 = ((int) Integer.toUnsignedLong(((Number) (x431)).intValue()) & 0x7ffffff);
  long x434 = (x432 + x365);
  long x435 = (x434 >>> 27);
  int x436 = ((int) Integer.toUnsignedLong(((Number) (x434)).intValue()) & 0x7ffffff);
  long x437 = ((long) Integer.toUnsignedLong(((Number) (x364)).intValue()) + x435);
  int x438 = (int) Integer.toUnsignedLong(((Number) ((x437 >>> 28))).intValue());
  int x439 = ((int) Integer.toUnsignedLong(((Number) (x437)).intValue()) & 0xfffffff);
  int x440 = (x438 + x385);
  int x441 = (x440 >>> 27);
  int x442 = (x440 & 0x7ffffff);
  int x443 = (x441 + x388);
  out1[0] = x439;
  out1[1] = x442;
  out1[2] = x443;
  out1[3] = x391;
  out1[4] = x394;
  out1[5] = x397;
  out1[6] = x400;
  out1[7] = x403;
  out1[8] = x406;
  out1[9] = x409;
  out1[10] = x412;
  out1[11] = x415;
  out1[12] = x418;
  out1[13] = x421;
  out1[14] = x424;
  out1[15] = x427;
  out1[16] = x430;
  out1[17] = x433;
  out1[18] = x436;
}

/**
 * The function fiat_P521_carry_square squares a field element and reduces the result. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = (eval arg1 * eval arg1) mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 */
public static void fiat_P521_carry_square(int[] out1, final int[] arg1) {
  int x1 = (arg1[18]);
  int x2 = (x1 * 0x2);
  int x3 = ((arg1[18]) * 0x2);
  int x4 = (arg1[17]);
  int x5 = (x4 * 0x2);
  int x6 = ((arg1[17]) * 0x2);
  int x7 = (arg1[16]);
  int x8 = (x7 * 0x2);
  int x9 = ((arg1[16]) * 0x2);
  int x10 = (arg1[15]);
  int x11 = (x10 * 0x2);
  int x12 = ((arg1[15]) * 0x2);
  int x13 = (arg1[14]);
  int x14 = (x13 * 0x2);
  int x15 = ((arg1[14]) * 0x2);
  int x16 = (arg1[13]);
  int x17 = (x16 * 0x2);
  int x18 = ((arg1[13]) * 0x2);
  int x19 = (arg1[12]);
  int x20 = (x19 * 0x2);
  int x21 = ((arg1[12]) * 0x2);
  int x22 = (arg1[11]);
  int x23 = (x22 * 0x2);
  int x24 = ((arg1[11]) * 0x2);
  int x25 = (arg1[10]);
  int x26 = (x25 * 0x2);
  int x27 = ((arg1[10]) * 0x2);
  int x28 = ((arg1[9]) * 0x2);
  int x29 = ((arg1[8]) * 0x2);
  int x30 = ((arg1[7]) * 0x2);
  int x31 = ((arg1[6]) * 0x2);
  int x32 = ((arg1[5]) * 0x2);
  int x33 = ((arg1[4]) * 0x2);
  int x34 = ((arg1[3]) * 0x2);
  int x35 = ((arg1[2]) * 0x2);
  int x36 = ((arg1[1]) * 0x2);
  long x37 = ((long) Integer.toUnsignedLong(((Number) ((arg1[18]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x1)).intValue()));
  long x38 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x39 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x4 * 0x2))).intValue()));
  long x40 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x41 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x42 = ((long) Integer.toUnsignedLong(((Number) ((arg1[16]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x7)).intValue()));
  long x43 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x44 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x45 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x46 = ((long) Integer.toUnsignedLong(((Number) ((arg1[15]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x10 * 0x2))).intValue()));
  long x47 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x48 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x5)).intValue()));
  long x49 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x50 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x11)).intValue()));
  long x51 = ((long) Integer.toUnsignedLong(((Number) ((arg1[14]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x13)).intValue()));
  long x52 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x53 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x54 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x55 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x56 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x57 = ((long) Integer.toUnsignedLong(((Number) ((arg1[13]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x16 * 0x2))).intValue()));
  long x58 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x59 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x60 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x8 * 0x2))).intValue()));
  long x61 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x62 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x14 * 0x2))).intValue()));
  long x63 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x17 * 0x2))).intValue()));
  long x64 = ((long) Integer.toUnsignedLong(((Number) ((arg1[12]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x19 * 0x2))).intValue()));
  long x65 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x66 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x67 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x68 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x69 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x70 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x17)).intValue()));
  long x71 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x20 * 0x2))).intValue()));
  long x72 = ((long) Integer.toUnsignedLong(((Number) ((arg1[11]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x22)).intValue()));
  long x73 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x74 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x75 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x8 * 0x2))).intValue()));
  long x76 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x77 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x78 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x17 * 0x2))).intValue()));
  long x79 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x20 * 0x2))).intValue()));
  long x80 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x23 * 0x2))).intValue()));
  long x81 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x25 * 0x2))).intValue()));
  long x82 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x83 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x84 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x85 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x11)).intValue()));
  long x86 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x87 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x17)).intValue()));
  long x88 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x20 * 0x2))).intValue()));
  long x89 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x23)).intValue()));
  long x90 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x26 * 0x2))).intValue()));
  long x91 = ((long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[9]))).intValue()));
  long x92 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x93 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x94 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x95 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x96 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x97 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x17 * 0x2))).intValue()));
  long x98 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x20 * 0x2))).intValue()));
  long x99 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x23 * 0x2))).intValue()));
  long x100 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x101 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x102 = ((long) Integer.toUnsignedLong(((Number) ((arg1[8]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg1[8]) * 0x2))).intValue()));
  long x103 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x104 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x5)).intValue()));
  long x105 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x106 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x11)).intValue()));
  long x107 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x108 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x17)).intValue()));
  long x109 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x20 * 0x2))).intValue()));
  long x110 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x111 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x27)).intValue()));
  long x112 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x113 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x29)).intValue()));
  long x114 = ((long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[7]))).intValue()));
  long x115 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x116 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x117 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x118 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x119 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x14)).intValue()));
  long x120 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x17 * 0x2))).intValue()));
  long x121 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x122 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x123 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x124 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x125 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x29 * 0x2))).intValue()));
  long x126 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x127 = ((long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[6]))).intValue()));
  long x128 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x129 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x130 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x8 * 0x2))).intValue()));
  long x131 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x132 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x14 * 0x2))).intValue()));
  long x133 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x18 * 0x2))).intValue()));
  long x134 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x135 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x24 * 0x2))).intValue()));
  long x136 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x137 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x28 * 0x2))).intValue()));
  long x138 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x29 * 0x2))).intValue()));
  long x139 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x140 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x31 * 0x2))).intValue()));
  long x141 = ((long) Integer.toUnsignedLong(((Number) ((arg1[5]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg1[5]) * 0x2))).intValue()));
  long x142 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x143 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x144 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x8)).intValue()));
  long x145 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x11 * 0x2))).intValue()));
  long x146 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x15)).intValue()));
  long x147 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x18)).intValue()));
  long x148 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x149 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x150 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x151 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x152 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x29)).intValue()));
  long x153 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x154 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x31)).intValue()));
  long x155 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x32 * 0x2))).intValue()));
  long x156 = ((long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[4]))).intValue()));
  long x157 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x158 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x159 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x8 * 0x2))).intValue()));
  long x160 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x12 * 0x2))).intValue()));
  long x161 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x15)).intValue()));
  long x162 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x18 * 0x2))).intValue()));
  long x163 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x164 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x24 * 0x2))).intValue()));
  long x165 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x166 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x167 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x29 * 0x2))).intValue()));
  long x168 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x169 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x31 * 0x2))).intValue()));
  long x170 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x32 * 0x2))).intValue()));
  long x171 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x33 * 0x2))).intValue()));
  long x172 = ((long) Integer.toUnsignedLong(((Number) ((arg1[3]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg1[3]) * 0x2))).intValue()));
  long x173 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x2)).intValue()));
  long x174 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x5 * 0x2))).intValue()));
  long x175 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x9)).intValue()));
  long x176 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x12)).intValue()));
  long x177 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x15)).intValue()));
  long x178 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x18)).intValue()));
  long x179 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x180 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x181 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x27)).intValue()));
  long x182 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x183 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x29)).intValue()));
  long x184 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x185 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x31)).intValue()));
  long x186 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x32 * 0x2))).intValue()));
  long x187 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x33)).intValue()));
  long x188 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x34)).intValue()));
  long x189 = ((long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[2]))).intValue()));
  long x190 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x2 * 0x2))).intValue()));
  long x191 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x6 * 0x2))).intValue()));
  long x192 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x9)).intValue()));
  long x193 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x12 * 0x2))).intValue()));
  long x194 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x15)).intValue()));
  long x195 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x18 * 0x2))).intValue()));
  long x196 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x21 * 0x2))).intValue()));
  long x197 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x198 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x27 * 0x2))).intValue()));
  long x199 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x200 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x29 * 0x2))).intValue()));
  long x201 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x202 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x31 * 0x2))).intValue()));
  long x203 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x32 * 0x2))).intValue()));
  long x204 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x33)).intValue()));
  long x205 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((x34 * 0x2))).intValue()));
  long x206 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x35)).intValue()));
  long x207 = ((long) Integer.toUnsignedLong(((Number) ((arg1[1]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (((arg1[1]) * 0x2))).intValue()));
  long x208 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x3)).intValue()));
  long x209 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x6)).intValue()));
  long x210 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x9)).intValue()));
  long x211 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x12)).intValue()));
  long x212 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x15)).intValue()));
  long x213 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x18)).intValue()));
  long x214 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x21)).intValue()));
  long x215 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x24)).intValue()));
  long x216 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x27)).intValue()));
  long x217 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x28)).intValue()));
  long x218 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x29)).intValue()));
  long x219 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x30)).intValue()));
  long x220 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x31)).intValue()));
  long x221 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x32)).intValue()));
  long x222 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x33)).intValue()));
  long x223 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x34)).intValue()));
  long x224 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x35)).intValue()));
  long x225 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) (x36)).intValue()));
  long x226 = ((long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()) * (long) Integer.toUnsignedLong(((Number) ((arg1[0]))).intValue()));
  long x227 = (x226 + (x190 + (x174 + (x159 + (x145 + (x132 + (x120 + (x109 + (x99 + x90)))))))));
  long x228 = (x227 >>> 28);
  int x229 = ((int) Integer.toUnsignedLong(((Number) (x227)).intValue()) & 0xfffffff);
  long x230 = (x208 + (x191 + (x175 + (x160 + (x146 + (x133 + (x121 + (x110 + (x100 + x91)))))))));
  long x231 = (x209 + (x192 + (x176 + (x161 + (x147 + (x134 + (x122 + (x111 + (x101 + x37)))))))));
  long x232 = (x210 + (x193 + (x177 + (x162 + (x148 + (x135 + (x123 + (x112 + (x102 + x38)))))))));
  long x233 = (x211 + (x194 + (x178 + (x163 + (x149 + (x136 + (x124 + (x113 + (x40 + x39)))))))));
  long x234 = (x212 + (x195 + (x179 + (x164 + (x150 + (x137 + (x125 + (x114 + (x43 + x41)))))))));
  long x235 = (x213 + (x196 + (x180 + (x165 + (x151 + (x138 + (x126 + (x47 + (x44 + x42)))))))));
  long x236 = (x214 + (x197 + (x181 + (x166 + (x152 + (x139 + (x127 + (x52 + (x48 + x45)))))))));
  long x237 = (x215 + (x198 + (x182 + (x167 + (x153 + (x140 + (x58 + (x53 + (x49 + x46)))))))));
  long x238 = (x216 + (x199 + (x183 + (x168 + (x154 + (x141 + (x65 + (x59 + (x54 + x50)))))))));
  long x239 = (x217 + (x200 + (x184 + (x169 + (x155 + (x73 + (x66 + (x60 + (x55 + x51)))))))));
  long x240 = (x218 + (x201 + (x185 + (x170 + (x156 + (x82 + (x74 + (x67 + (x61 + x56)))))))));
  long x241 = (x219 + (x202 + (x186 + (x171 + (x92 + (x83 + (x75 + (x68 + (x62 + x57)))))))));
  long x242 = (x220 + (x203 + (x187 + (x172 + (x103 + (x93 + (x84 + (x76 + (x69 + x63)))))))));
  long x243 = (x221 + (x204 + (x188 + (x115 + (x104 + (x94 + (x85 + (x77 + (x70 + x64)))))))));
  long x244 = (x222 + (x205 + (x189 + (x128 + (x116 + (x105 + (x95 + (x86 + (x78 + x71)))))))));
  long x245 = (x223 + (x206 + (x142 + (x129 + (x117 + (x106 + (x96 + (x87 + (x79 + x72)))))))));
  long x246 = (x224 + (x207 + (x157 + (x143 + (x130 + (x118 + (x107 + (x97 + (x88 + x80)))))))));
  long x247 = (x225 + (x173 + (x158 + (x144 + (x131 + (x119 + (x108 + (x98 + (x89 + x81)))))))));
  long x248 = (x228 + x247);
  long x249 = (x248 >>> 27);
  int x250 = ((int) Integer.toUnsignedLong(((Number) (x248)).intValue()) & 0x7ffffff);
  long x251 = (x249 + x246);
  long x252 = (x251 >>> 28);
  int x253 = ((int) Integer.toUnsignedLong(((Number) (x251)).intValue()) & 0xfffffff);
  long x254 = (x252 + x245);
  long x255 = (x254 >>> 27);
  int x256 = ((int) Integer.toUnsignedLong(((Number) (x254)).intValue()) & 0x7ffffff);
  long x257 = (x255 + x244);
  long x258 = (x257 >>> 28);
  int x259 = ((int) Integer.toUnsignedLong(((Number) (x257)).intValue()) & 0xfffffff);
  long x260 = (x258 + x243);
  long x261 = (x260 >>> 27);
  int x262 = ((int) Integer.toUnsignedLong(((Number) (x260)).intValue()) & 0x7ffffff);
  long x263 = (x261 + x242);
  long x264 = (x263 >>> 27);
  int x265 = ((int) Integer.toUnsignedLong(((Number) (x263)).intValue()) & 0x7ffffff);
  long x266 = (x264 + x241);
  long x267 = (x266 >>> 28);
  int x268 = ((int) Integer.toUnsignedLong(((Number) (x266)).intValue()) & 0xfffffff);
  long x269 = (x267 + x240);
  long x270 = (x269 >>> 27);
  int x271 = ((int) Integer.toUnsignedLong(((Number) (x269)).intValue()) & 0x7ffffff);
  long x272 = (x270 + x239);
  long x273 = (x272 >>> 28);
  int x274 = ((int) Integer.toUnsignedLong(((Number) (x272)).intValue()) & 0xfffffff);
  long x275 = (x273 + x238);
  long x276 = (x275 >>> 27);
  int x277 = ((int) Integer.toUnsignedLong(((Number) (x275)).intValue()) & 0x7ffffff);
  long x278 = (x276 + x237);
  long x279 = (x278 >>> 28);
  int x280 = ((int) Integer.toUnsignedLong(((Number) (x278)).intValue()) & 0xfffffff);
  long x281 = (x279 + x236);
  long x282 = (x281 >>> 27);
  int x283 = ((int) Integer.toUnsignedLong(((Number) (x281)).intValue()) & 0x7ffffff);
  long x284 = (x282 + x235);
  long x285 = (x284 >>> 27);
  int x286 = ((int) Integer.toUnsignedLong(((Number) (x284)).intValue()) & 0x7ffffff);
  long x287 = (x285 + x234);
  long x288 = (x287 >>> 28);
  int x289 = ((int) Integer.toUnsignedLong(((Number) (x287)).intValue()) & 0xfffffff);
  long x290 = (x288 + x233);
  long x291 = (x290 >>> 27);
  int x292 = ((int) Integer.toUnsignedLong(((Number) (x290)).intValue()) & 0x7ffffff);
  long x293 = (x291 + x232);
  long x294 = (x293 >>> 28);
  int x295 = ((int) Integer.toUnsignedLong(((Number) (x293)).intValue()) & 0xfffffff);
  long x296 = (x294 + x231);
  long x297 = (x296 >>> 27);
  int x298 = ((int) Integer.toUnsignedLong(((Number) (x296)).intValue()) & 0x7ffffff);
  long x299 = (x297 + x230);
  long x300 = (x299 >>> 27);
  int x301 = ((int) Integer.toUnsignedLong(((Number) (x299)).intValue()) & 0x7ffffff);
  long x302 = ((long) Integer.toUnsignedLong(((Number) (x229)).intValue()) + x300);
  int x303 = (int) Integer.toUnsignedLong(((Number) ((x302 >>> 28))).intValue());
  int x304 = ((int) Integer.toUnsignedLong(((Number) (x302)).intValue()) & 0xfffffff);
  int x305 = (x303 + x250);
  int x306 = (x305 >>> 27);
  int x307 = (x305 & 0x7ffffff);
  int x308 = (x306 + x253);
  out1[0] = x304;
  out1[1] = x307;
  out1[2] = x308;
  out1[3] = x256;
  out1[4] = x259;
  out1[5] = x262;
  out1[6] = x265;
  out1[7] = x268;
  out1[8] = x271;
  out1[9] = x274;
  out1[10] = x277;
  out1[11] = x280;
  out1[12] = x283;
  out1[13] = x286;
  out1[14] = x289;
  out1[15] = x292;
  out1[16] = x295;
  out1[17] = x298;
  out1[18] = x301;
}

/**
 * The function fiat_P521_carry reduces a field element. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = eval arg1 mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 */
public static void fiat_P521_carry(int[] out1, final int[] arg1) {
  int x1 = (arg1[0]);
  int x2 = ((x1 >>> 28) + (arg1[1]));
  int x3 = ((x2 >>> 27) + (arg1[2]));
  int x4 = ((x3 >>> 28) + (arg1[3]));
  int x5 = ((x4 >>> 27) + (arg1[4]));
  int x6 = ((x5 >>> 28) + (arg1[5]));
  int x7 = ((x6 >>> 27) + (arg1[6]));
  int x8 = ((x7 >>> 27) + (arg1[7]));
  int x9 = ((x8 >>> 28) + (arg1[8]));
  int x10 = ((x9 >>> 27) + (arg1[9]));
  int x11 = ((x10 >>> 28) + (arg1[10]));
  int x12 = ((x11 >>> 27) + (arg1[11]));
  int x13 = ((x12 >>> 28) + (arg1[12]));
  int x14 = ((x13 >>> 27) + (arg1[13]));
  int x15 = ((x14 >>> 27) + (arg1[14]));
  int x16 = ((x15 >>> 28) + (arg1[15]));
  int x17 = ((x16 >>> 27) + (arg1[16]));
  int x18 = ((x17 >>> 28) + (arg1[17]));
  int x19 = ((x18 >>> 27) + (arg1[18]));
  int x20 = ((x1 & 0xfffffff) + (x19 >>> 27));
  int x21 = ((x20 >>> 28) + (x2 & 0x7ffffff));
  int x22 = (x20 & 0xfffffff);
  int x23 = (x21 & 0x7ffffff);
  int x24 = ((x21 >>> 27) + (x3 & 0xfffffff));
  int x25 = (x4 & 0x7ffffff);
  int x26 = (x5 & 0xfffffff);
  int x27 = (x6 & 0x7ffffff);
  int x28 = (x7 & 0x7ffffff);
  int x29 = (x8 & 0xfffffff);
  int x30 = (x9 & 0x7ffffff);
  int x31 = (x10 & 0xfffffff);
  int x32 = (x11 & 0x7ffffff);
  int x33 = (x12 & 0xfffffff);
  int x34 = (x13 & 0x7ffffff);
  int x35 = (x14 & 0x7ffffff);
  int x36 = (x15 & 0xfffffff);
  int x37 = (x16 & 0x7ffffff);
  int x38 = (x17 & 0xfffffff);
  int x39 = (x18 & 0x7ffffff);
  int x40 = (x19 & 0x7ffffff);
  out1[0] = x22;
  out1[1] = x23;
  out1[2] = x24;
  out1[3] = x25;
  out1[4] = x26;
  out1[5] = x27;
  out1[6] = x28;
  out1[7] = x29;
  out1[8] = x30;
  out1[9] = x31;
  out1[10] = x32;
  out1[11] = x33;
  out1[12] = x34;
  out1[13] = x35;
  out1[14] = x36;
  out1[15] = x37;
  out1[16] = x38;
  out1[17] = x39;
  out1[18] = x40;
}

/**
 * The function fiat_P521_add adds two field elements. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = (eval arg1 + eval arg2) mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 *   arg2: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 */
public static void fiat_P521_add(int[] out1, final int[] arg1, final int[] arg2) {
  int x1 = ((arg1[0]) + (arg2[0]));
  int x2 = ((arg1[1]) + (arg2[1]));
  int x3 = ((arg1[2]) + (arg2[2]));
  int x4 = ((arg1[3]) + (arg2[3]));
  int x5 = ((arg1[4]) + (arg2[4]));
  int x6 = ((arg1[5]) + (arg2[5]));
  int x7 = ((arg1[6]) + (arg2[6]));
  int x8 = ((arg1[7]) + (arg2[7]));
  int x9 = ((arg1[8]) + (arg2[8]));
  int x10 = ((arg1[9]) + (arg2[9]));
  int x11 = ((arg1[10]) + (arg2[10]));
  int x12 = ((arg1[11]) + (arg2[11]));
  int x13 = ((arg1[12]) + (arg2[12]));
  int x14 = ((arg1[13]) + (arg2[13]));
  int x15 = ((arg1[14]) + (arg2[14]));
  int x16 = ((arg1[15]) + (arg2[15]));
  int x17 = ((arg1[16]) + (arg2[16]));
  int x18 = ((arg1[17]) + (arg2[17]));
  int x19 = ((arg1[18]) + (arg2[18]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
  out1[18] = x19;
}

/**
 * The function fiat_P521_sub subtracts two field elements. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = (eval arg1 - eval arg2) mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 *   arg2: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 */
public static void fiat_P521_sub(int[] out1, final int[] arg1, final int[] arg2) {
  int x1 = ((0x1ffffffe + (arg1[0])) - (arg2[0]));
  int x2 = ((0xffffffe + (arg1[1])) - (arg2[1]));
  int x3 = ((0x1ffffffe + (arg1[2])) - (arg2[2]));
  int x4 = ((0xffffffe + (arg1[3])) - (arg2[3]));
  int x5 = ((0x1ffffffe + (arg1[4])) - (arg2[4]));
  int x6 = ((0xffffffe + (arg1[5])) - (arg2[5]));
  int x7 = ((0xffffffe + (arg1[6])) - (arg2[6]));
  int x8 = ((0x1ffffffe + (arg1[7])) - (arg2[7]));
  int x9 = ((0xffffffe + (arg1[8])) - (arg2[8]));
  int x10 = ((0x1ffffffe + (arg1[9])) - (arg2[9]));
  int x11 = ((0xffffffe + (arg1[10])) - (arg2[10]));
  int x12 = ((0x1ffffffe + (arg1[11])) - (arg2[11]));
  int x13 = ((0xffffffe + (arg1[12])) - (arg2[12]));
  int x14 = ((0xffffffe + (arg1[13])) - (arg2[13]));
  int x15 = ((0x1ffffffe + (arg1[14])) - (arg2[14]));
  int x16 = ((0xffffffe + (arg1[15])) - (arg2[15]));
  int x17 = ((0x1ffffffe + (arg1[16])) - (arg2[16]));
  int x18 = ((0xffffffe + (arg1[17])) - (arg2[17]));
  int x19 = ((0xffffffe + (arg1[18])) - (arg2[18]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
  out1[18] = x19;
}

/**
 * The function fiat_P521_opp negates a field element. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = -eval arg1 mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 */
public static void fiat_P521_opp(int[] out1, final int[] arg1) {
  int x1 = (0x1ffffffe - (arg1[0]));
  int x2 = (0xffffffe - (arg1[1]));
  int x3 = (0x1ffffffe - (arg1[2]));
  int x4 = (0xffffffe - (arg1[3]));
  int x5 = (0x1ffffffe - (arg1[4]));
  int x6 = (0xffffffe - (arg1[5]));
  int x7 = (0xffffffe - (arg1[6]));
  int x8 = (0x1ffffffe - (arg1[7]));
  int x9 = (0xffffffe - (arg1[8]));
  int x10 = (0x1ffffffe - (arg1[9]));
  int x11 = (0xffffffe - (arg1[10]));
  int x12 = (0x1ffffffe - (arg1[11]));
  int x13 = (0xffffffe - (arg1[12]));
  int x14 = (0xffffffe - (arg1[13]));
  int x15 = (0x1ffffffe - (arg1[14]));
  int x16 = (0xffffffe - (arg1[15]));
  int x17 = (0x1ffffffe - (arg1[16]));
  int x18 = (0xffffffe - (arg1[17]));
  int x19 = (0xffffffe - (arg1[18]));
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
  out1[18] = x19;
}

/**
 * The function fiat_P521_selectznz is a multi-limb conditional select. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = (if arg1 = 0 then arg2 else arg3) <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [0x0 ~&gt; 0x1] <p>
 *   arg2: [[0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff]] <p>
 *   arg3: [[0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff], [0x0 ~&gt; 0xffffffff]] <p>
 */
public static void fiat_P521_selectznz(int[] out1, int arg1, final int[] arg2, final int[] arg3) {
  Box<Integer> x1 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x1, arg1, (arg2[0]), (arg3[0]));
  Box<Integer> x2 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x2, arg1, (arg2[1]), (arg3[1]));
  Box<Integer> x3 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x3, arg1, (arg2[2]), (arg3[2]));
  Box<Integer> x4 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x4, arg1, (arg2[3]), (arg3[3]));
  Box<Integer> x5 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x5, arg1, (arg2[4]), (arg3[4]));
  Box<Integer> x6 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x6, arg1, (arg2[5]), (arg3[5]));
  Box<Integer> x7 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x7, arg1, (arg2[6]), (arg3[6]));
  Box<Integer> x8 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x8, arg1, (arg2[7]), (arg3[7]));
  Box<Integer> x9 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x9, arg1, (arg2[8]), (arg3[8]));
  Box<Integer> x10 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x10, arg1, (arg2[9]), (arg3[9]));
  Box<Integer> x11 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x11, arg1, (arg2[10]), (arg3[10]));
  Box<Integer> x12 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x12, arg1, (arg2[11]), (arg3[11]));
  Box<Integer> x13 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x13, arg1, (arg2[12]), (arg3[12]));
  Box<Integer> x14 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x14, arg1, (arg2[13]), (arg3[13]));
  Box<Integer> x15 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x15, arg1, (arg2[14]), (arg3[14]));
  Box<Integer> x16 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x16, arg1, (arg2[15]), (arg3[15]));
  Box<Integer> x17 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x17, arg1, (arg2[16]), (arg3[16]));
  Box<Integer> x18 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x18, arg1, (arg2[17]), (arg3[17]));
  Box<Integer> x19 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x19, arg1, (arg2[18]), (arg3[18]));
  out1[0] = (x1).get();
  out1[1] = (x2).get();
  out1[2] = (x3).get();
  out1[3] = (x4).get();
  out1[4] = (x5).get();
  out1[5] = (x6).get();
  out1[6] = (x7).get();
  out1[7] = (x8).get();
  out1[8] = (x9).get();
  out1[9] = (x10).get();
  out1[10] = (x11).get();
  out1[11] = (x12).get();
  out1[12] = (x13).get();
  out1[13] = (x14).get();
  out1[14] = (x15).get();
  out1[15] = (x16).get();
  out1[16] = (x17).get();
  out1[17] = (x18).get();
  out1[18] = (x19).get();
}

/**
 * The function fiat_P521_to_bytes serializes a field element to bytes in little-endian order. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = map (λ x, ⌊((eval arg1 mod m) mod 2^(8 * (x + 1))) / 2^(8 * x)⌋) [0..65] <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0x1]] <p>
 */
public static void fiat_P521_to_bytes(int[] out1, final int[] arg1) {
  Box<Integer> x1 = new Box<Integer>((int)0);
  Box<Integer> x2 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x1, x2, (int) Integer.toUnsignedLong(((Number) (0x0)).intValue()), (arg1[0]), 0xfffffff);
  Box<Integer> x3 = new Box<Integer>((int)0);
  Box<Integer> x4 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x3, x4, (x2).get(), (arg1[1]), 0x7ffffff);
  Box<Integer> x5 = new Box<Integer>((int)0);
  Box<Integer> x6 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x5, x6, (x4).get(), (arg1[2]), 0xfffffff);
  Box<Integer> x7 = new Box<Integer>((int)0);
  Box<Integer> x8 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x7, x8, (x6).get(), (arg1[3]), 0x7ffffff);
  Box<Integer> x9 = new Box<Integer>((int)0);
  Box<Integer> x10 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x9, x10, (x8).get(), (arg1[4]), 0xfffffff);
  Box<Integer> x11 = new Box<Integer>((int)0);
  Box<Integer> x12 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x11, x12, (x10).get(), (arg1[5]), 0x7ffffff);
  Box<Integer> x13 = new Box<Integer>((int)0);
  Box<Integer> x14 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x13, x14, (x12).get(), (arg1[6]), 0x7ffffff);
  Box<Integer> x15 = new Box<Integer>((int)0);
  Box<Integer> x16 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x15, x16, (x14).get(), (arg1[7]), 0xfffffff);
  Box<Integer> x17 = new Box<Integer>((int)0);
  Box<Integer> x18 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x17, x18, (x16).get(), (arg1[8]), 0x7ffffff);
  Box<Integer> x19 = new Box<Integer>((int)0);
  Box<Integer> x20 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x19, x20, (x18).get(), (arg1[9]), 0xfffffff);
  Box<Integer> x21 = new Box<Integer>((int)0);
  Box<Integer> x22 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x21, x22, (x20).get(), (arg1[10]), 0x7ffffff);
  Box<Integer> x23 = new Box<Integer>((int)0);
  Box<Integer> x24 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x23, x24, (x22).get(), (arg1[11]), 0xfffffff);
  Box<Integer> x25 = new Box<Integer>((int)0);
  Box<Integer> x26 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x25, x26, (x24).get(), (arg1[12]), 0x7ffffff);
  Box<Integer> x27 = new Box<Integer>((int)0);
  Box<Integer> x28 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x27, x28, (x26).get(), (arg1[13]), 0x7ffffff);
  Box<Integer> x29 = new Box<Integer>((int)0);
  Box<Integer> x30 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x29, x30, (x28).get(), (arg1[14]), 0xfffffff);
  Box<Integer> x31 = new Box<Integer>((int)0);
  Box<Integer> x32 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x31, x32, (x30).get(), (arg1[15]), 0x7ffffff);
  Box<Integer> x33 = new Box<Integer>((int)0);
  Box<Integer> x34 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u28(x33, x34, (x32).get(), (arg1[16]), 0xfffffff);
  Box<Integer> x35 = new Box<Integer>((int)0);
  Box<Integer> x36 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x35, x36, (x34).get(), (arg1[17]), 0x7ffffff);
  Box<Integer> x37 = new Box<Integer>((int)0);
  Box<Integer> x38 = new Box<Integer>((int)0);
  fiat_P521_subborrowx_u27(x37, x38, (x36).get(), (arg1[18]), 0x7ffffff);
  Box<Integer> x39 = new Box<Integer>((int)0);
  fiat_P521_cmovznz_u32(x39, (x38).get(), (int) Integer.toUnsignedLong(((Number) (0x0)).intValue()), 0xffffffff);
  Box<Integer> x40 = new Box<Integer>((int)0);
  Box<Integer> x41 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x40, x41, 0x0, (x1).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x42 = new Box<Integer>((int)0);
  Box<Integer> x43 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x42, x43, (x41).get(), (x3).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x44 = new Box<Integer>((int)0);
  Box<Integer> x45 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x44, x45, (x43).get(), (x5).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x46 = new Box<Integer>((int)0);
  Box<Integer> x47 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x46, x47, (x45).get(), (x7).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x48 = new Box<Integer>((int)0);
  Box<Integer> x49 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x48, x49, (x47).get(), (x9).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x50 = new Box<Integer>((int)0);
  Box<Integer> x51 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x50, x51, (x49).get(), (x11).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x52 = new Box<Integer>((int)0);
  Box<Integer> x53 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x52, x53, (x51).get(), (x13).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x54 = new Box<Integer>((int)0);
  Box<Integer> x55 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x54, x55, (x53).get(), (x15).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x56 = new Box<Integer>((int)0);
  Box<Integer> x57 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x56, x57, (x55).get(), (x17).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x58 = new Box<Integer>((int)0);
  Box<Integer> x59 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x58, x59, (x57).get(), (x19).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x60 = new Box<Integer>((int)0);
  Box<Integer> x61 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x60, x61, (x59).get(), (x21).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x62 = new Box<Integer>((int)0);
  Box<Integer> x63 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x62, x63, (x61).get(), (x23).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x64 = new Box<Integer>((int)0);
  Box<Integer> x65 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x64, x65, (x63).get(), (x25).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x66 = new Box<Integer>((int)0);
  Box<Integer> x67 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x66, x67, (x65).get(), (x27).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x68 = new Box<Integer>((int)0);
  Box<Integer> x69 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x68, x69, (x67).get(), (x29).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x70 = new Box<Integer>((int)0);
  Box<Integer> x71 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x70, x71, (x69).get(), (x31).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x72 = new Box<Integer>((int)0);
  Box<Integer> x73 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u28(x72, x73, (x71).get(), (x33).get(), ((x39).get() & 0xfffffff));
  Box<Integer> x74 = new Box<Integer>((int)0);
  Box<Integer> x75 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x74, x75, (x73).get(), (x35).get(), ((x39).get() & 0x7ffffff));
  Box<Integer> x76 = new Box<Integer>((int)0);
  Box<Integer> x77 = new Box<Integer>((int)0);
  fiat_P521_addcarryx_u27(x76, x77, (x75).get(), (x37).get(), ((x39).get() & 0x7ffffff));
  long x78 = ((long) Integer.toUnsignedLong(((Number) ((x76).get())).intValue()) << 6);
  int x79 = ((x74).get() << 3);
  long x80 = ((long) Integer.toUnsignedLong(((Number) ((x72).get())).intValue()) << 7);
  int x81 = ((x70).get() << 4);
  int x82 = ((x66).get() << 5);
  int x83 = ((x64).get() << 2);
  long x84 = ((long) Integer.toUnsignedLong(((Number) ((x62).get())).intValue()) << 6);
  int x85 = ((x60).get() << 3);
  long x86 = ((long) Integer.toUnsignedLong(((Number) ((x58).get())).intValue()) << 7);
  int x87 = ((x56).get() << 4);
  int x88 = ((x52).get() << 5);
  int x89 = ((x50).get() << 2);
  long x90 = ((long) Integer.toUnsignedLong(((Number) ((x48).get())).intValue()) << 6);
  int x91 = ((x46).get() << 3);
  long x92 = ((long) Integer.toUnsignedLong(((Number) ((x44).get())).intValue()) << 7);
  int x93 = ((x42).get() << 4);
  int x94 = ((x40).get() & 0xff);
  int x95 = ((x40).get() >>> 8);
  int x96 = (x95 & 0xff);
  int x97 = (x95 >>> 8);
  int x98 = (x97 & 0xff);
  int x99 = (x97 >>> 8);
  int x100 = (x93 + x99);
  int x101 = (x100 & 0xff);
  int x102 = (x100 >>> 8);
  int x103 = (x102 & 0xff);
  int x104 = (x102 >>> 8);
  int x105 = (x104 & 0xff);
  int x106 = (x104 >>> 8);
  long x107 = (x92 + (long) Integer.toUnsignedLong(((Number) (x106)).intValue()));
  int x108 = ((int) Integer.toUnsignedLong(((Number) (x107)).intValue()) & 0xff);
  int x109 = (int) Integer.toUnsignedLong(((Number) ((x107 >>> 8))).intValue());
  int x110 = (x109 & 0xff);
  int x111 = (x109 >>> 8);
  int x112 = (x111 & 0xff);
  int x113 = (x111 >>> 8);
  int x114 = (x113 & 0xff);
  int x115 = (x113 >>> 8);
  int x116 = (x91 + x115);
  int x117 = (x116 & 0xff);
  int x118 = (x116 >>> 8);
  int x119 = (x118 & 0xff);
  int x120 = (x118 >>> 8);
  int x121 = (x120 & 0xff);
  int x122 = (x120 >>> 8);
  long x123 = (x90 + (long) Integer.toUnsignedLong(((Number) (x122)).intValue()));
  int x124 = ((int) Integer.toUnsignedLong(((Number) (x123)).intValue()) & 0xff);
  int x125 = (int) Integer.toUnsignedLong(((Number) ((x123 >>> 8))).intValue());
  int x126 = (x125 & 0xff);
  int x127 = (x125 >>> 8);
  int x128 = (x127 & 0xff);
  int x129 = (x127 >>> 8);
  int x130 = (x129 & 0xff);
  int x131 = (x129 >>> 8);
  int x132 = (x89 + x131);
  int x133 = (x132 & 0xff);
  int x134 = (x132 >>> 8);
  int x135 = (x134 & 0xff);
  int x136 = (x134 >>> 8);
  int x137 = (x136 & 0xff);
  int x138 = (x136 >>> 8);
  int x139 = (x88 + x138);
  int x140 = (x139 & 0xff);
  int x141 = (x139 >>> 8);
  int x142 = (x141 & 0xff);
  int x143 = (x141 >>> 8);
  int x144 = (x143 & 0xff);
  int x145 = (x143 >>> 8);
  int x146 = ((x54).get() & 0xff);
  int x147 = ((x54).get() >>> 8);
  int x148 = (x147 & 0xff);
  int x149 = (x147 >>> 8);
  int x150 = (x149 & 0xff);
  int x151 = (x149 >>> 8);
  int x152 = (x87 + x151);
  int x153 = (x152 & 0xff);
  int x154 = (x152 >>> 8);
  int x155 = (x154 & 0xff);
  int x156 = (x154 >>> 8);
  int x157 = (x156 & 0xff);
  int x158 = (x156 >>> 8);
  long x159 = (x86 + (long) Integer.toUnsignedLong(((Number) (x158)).intValue()));
  int x160 = ((int) Integer.toUnsignedLong(((Number) (x159)).intValue()) & 0xff);
  int x161 = (int) Integer.toUnsignedLong(((Number) ((x159 >>> 8))).intValue());
  int x162 = (x161 & 0xff);
  int x163 = (x161 >>> 8);
  int x164 = (x163 & 0xff);
  int x165 = (x163 >>> 8);
  int x166 = (x165 & 0xff);
  int x167 = (x165 >>> 8);
  int x168 = (x85 + x167);
  int x169 = (x168 & 0xff);
  int x170 = (x168 >>> 8);
  int x171 = (x170 & 0xff);
  int x172 = (x170 >>> 8);
  int x173 = (x172 & 0xff);
  int x174 = (x172 >>> 8);
  long x175 = (x84 + (long) Integer.toUnsignedLong(((Number) (x174)).intValue()));
  int x176 = ((int) Integer.toUnsignedLong(((Number) (x175)).intValue()) & 0xff);
  int x177 = (int) Integer.toUnsignedLong(((Number) ((x175 >>> 8))).intValue());
  int x178 = (x177 & 0xff);
  int x179 = (x177 >>> 8);
  int x180 = (x179 & 0xff);
  int x181 = (x179 >>> 8);
  int x182 = (x181 & 0xff);
  int x183 = (x181 >>> 8);
  int x184 = (x83 + x183);
  int x185 = (x184 & 0xff);
  int x186 = (x184 >>> 8);
  int x187 = (x186 & 0xff);
  int x188 = (x186 >>> 8);
  int x189 = (x188 & 0xff);
  int x190 = (x188 >>> 8);
  int x191 = (x82 + x190);
  int x192 = (x191 & 0xff);
  int x193 = (x191 >>> 8);
  int x194 = (x193 & 0xff);
  int x195 = (x193 >>> 8);
  int x196 = (x195 & 0xff);
  int x197 = (x195 >>> 8);
  int x198 = ((x68).get() & 0xff);
  int x199 = ((x68).get() >>> 8);
  int x200 = (x199 & 0xff);
  int x201 = (x199 >>> 8);
  int x202 = (x201 & 0xff);
  int x203 = (x201 >>> 8);
  int x204 = (x81 + x203);
  int x205 = (x204 & 0xff);
  int x206 = (x204 >>> 8);
  int x207 = (x206 & 0xff);
  int x208 = (x206 >>> 8);
  int x209 = (x208 & 0xff);
  int x210 = (x208 >>> 8);
  long x211 = (x80 + (long) Integer.toUnsignedLong(((Number) (x210)).intValue()));
  int x212 = ((int) Integer.toUnsignedLong(((Number) (x211)).intValue()) & 0xff);
  int x213 = (int) Integer.toUnsignedLong(((Number) ((x211 >>> 8))).intValue());
  int x214 = (x213 & 0xff);
  int x215 = (x213 >>> 8);
  int x216 = (x215 & 0xff);
  int x217 = (x215 >>> 8);
  int x218 = (x217 & 0xff);
  int x219 = (x217 >>> 8);
  int x220 = (x79 + x219);
  int x221 = (x220 & 0xff);
  int x222 = (x220 >>> 8);
  int x223 = (x222 & 0xff);
  int x224 = (x222 >>> 8);
  int x225 = (x224 & 0xff);
  int x226 = (x224 >>> 8);
  long x227 = (x78 + (long) Integer.toUnsignedLong(((Number) (x226)).intValue()));
  int x228 = ((int) Integer.toUnsignedLong(((Number) (x227)).intValue()) & 0xff);
  int x229 = (int) Integer.toUnsignedLong(((Number) ((x227 >>> 8))).intValue());
  int x230 = (x229 & 0xff);
  int x231 = (x229 >>> 8);
  int x232 = (x231 & 0xff);
  int x233 = (x231 >>> 8);
  int x234 = (x233 & 0xff);
  int x235 = (x233 >>> 8);
  out1[0] = x94;
  out1[1] = x96;
  out1[2] = x98;
  out1[3] = x101;
  out1[4] = x103;
  out1[5] = x105;
  out1[6] = x108;
  out1[7] = x110;
  out1[8] = x112;
  out1[9] = x114;
  out1[10] = x117;
  out1[11] = x119;
  out1[12] = x121;
  out1[13] = x124;
  out1[14] = x126;
  out1[15] = x128;
  out1[16] = x130;
  out1[17] = x133;
  out1[18] = x135;
  out1[19] = x137;
  out1[20] = x140;
  out1[21] = x142;
  out1[22] = x144;
  out1[23] = x145;
  out1[24] = x146;
  out1[25] = x148;
  out1[26] = x150;
  out1[27] = x153;
  out1[28] = x155;
  out1[29] = x157;
  out1[30] = x160;
  out1[31] = x162;
  out1[32] = x164;
  out1[33] = x166;
  out1[34] = x169;
  out1[35] = x171;
  out1[36] = x173;
  out1[37] = x176;
  out1[38] = x178;
  out1[39] = x180;
  out1[40] = x182;
  out1[41] = x185;
  out1[42] = x187;
  out1[43] = x189;
  out1[44] = x192;
  out1[45] = x194;
  out1[46] = x196;
  out1[47] = x197;
  out1[48] = x198;
  out1[49] = x200;
  out1[50] = x202;
  out1[51] = x205;
  out1[52] = x207;
  out1[53] = x209;
  out1[54] = x212;
  out1[55] = x214;
  out1[56] = x216;
  out1[57] = x218;
  out1[58] = x221;
  out1[59] = x223;
  out1[60] = x225;
  out1[61] = x228;
  out1[62] = x230;
  out1[63] = x232;
  out1[64] = x234;
  out1[65] = x235;
}

/**
 * The function fiat_P521_from_bytes deserializes a field element from bytes in little-endian order. <p>
 * <p>
 * Postconditions: <p>
 *   eval out1 mod m = bytes_eval arg1 mod m <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0xff], [0x0 ~&gt; 0x1]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 */
public static void fiat_P521_from_bytes(int[] out1, final int[] arg1) {
  int x1 = ((arg1[65]) << 26);
  int x2 = ((arg1[64]) << 18);
  int x3 = ((arg1[63]) << 10);
  int x4 = ((arg1[62]) << 2);
  int x5 = ((arg1[61]) << 21);
  int x6 = ((arg1[60]) << 13);
  int x7 = ((arg1[59]) << 5);
  long x8 = ((long) Integer.toUnsignedLong(((Number) ((arg1[58]))).intValue()) << 25);
  int x9 = ((arg1[57]) << 17);
  int x10 = ((arg1[56]) << 9);
  int x11 = ((arg1[55]) * 0x2);
  int x12 = ((arg1[54]) << 20);
  int x13 = ((arg1[53]) << 12);
  int x14 = ((arg1[52]) << 4);
  int x15 = ((arg1[51]) << 24);
  int x16 = ((arg1[50]) << 16);
  int x17 = ((arg1[49]) << 8);
  int x18 = (arg1[48]);
  int x19 = ((arg1[47]) << 19);
  int x20 = ((arg1[46]) << 11);
  int x21 = ((arg1[45]) << 3);
  int x22 = ((arg1[44]) << 22);
  int x23 = ((arg1[43]) << 14);
  int x24 = ((arg1[42]) << 6);
  long x25 = ((long) Integer.toUnsignedLong(((Number) ((arg1[41]))).intValue()) << 26);
  int x26 = ((arg1[40]) << 18);
  int x27 = ((arg1[39]) << 10);
  int x28 = ((arg1[38]) << 2);
  int x29 = ((arg1[37]) << 21);
  int x30 = ((arg1[36]) << 13);
  int x31 = ((arg1[35]) << 5);
  long x32 = ((long) Integer.toUnsignedLong(((Number) ((arg1[34]))).intValue()) << 25);
  int x33 = ((arg1[33]) << 17);
  int x34 = ((arg1[32]) << 9);
  int x35 = ((arg1[31]) * 0x2);
  int x36 = ((arg1[30]) << 20);
  int x37 = ((arg1[29]) << 12);
  int x38 = ((arg1[28]) << 4);
  int x39 = ((arg1[27]) << 24);
  int x40 = ((arg1[26]) << 16);
  int x41 = ((arg1[25]) << 8);
  int x42 = (arg1[24]);
  int x43 = ((arg1[23]) << 19);
  int x44 = ((arg1[22]) << 11);
  int x45 = ((arg1[21]) << 3);
  int x46 = ((arg1[20]) << 22);
  int x47 = ((arg1[19]) << 14);
  int x48 = ((arg1[18]) << 6);
  long x49 = ((long) Integer.toUnsignedLong(((Number) ((arg1[17]))).intValue()) << 26);
  int x50 = ((arg1[16]) << 18);
  int x51 = ((arg1[15]) << 10);
  int x52 = ((arg1[14]) << 2);
  int x53 = ((arg1[13]) << 21);
  int x54 = ((arg1[12]) << 13);
  int x55 = ((arg1[11]) << 5);
  long x56 = ((long) Integer.toUnsignedLong(((Number) ((arg1[10]))).intValue()) << 25);
  int x57 = ((arg1[9]) << 17);
  int x58 = ((arg1[8]) << 9);
  int x59 = ((arg1[7]) * 0x2);
  int x60 = ((arg1[6]) << 20);
  int x61 = ((arg1[5]) << 12);
  int x62 = ((arg1[4]) << 4);
  int x63 = ((arg1[3]) << 24);
  int x64 = ((arg1[2]) << 16);
  int x65 = ((arg1[1]) << 8);
  int x66 = (arg1[0]);
  int x67 = (x65 + x66);
  int x68 = (x64 + x67);
  int x69 = (x63 + x68);
  int x70 = (x69 & 0xfffffff);
  int x71 = (x69 >>> 28);
  int x72 = (x62 + x71);
  int x73 = (x61 + x72);
  int x74 = (x60 + x73);
  int x75 = (x74 & 0x7ffffff);
  int x76 = (x74 >>> 27);
  int x77 = (x59 + x76);
  int x78 = (x58 + x77);
  int x79 = (x57 + x78);
  long x80 = (x56 + (long) Integer.toUnsignedLong(((Number) (x79)).intValue()));
  int x81 = ((int) Integer.toUnsignedLong(((Number) (x80)).intValue()) & 0xfffffff);
  int x82 = (int) Integer.toUnsignedLong(((Number) ((x80 >>> 28))).intValue());
  int x83 = (x55 + x82);
  int x84 = (x54 + x83);
  int x85 = (x53 + x84);
  int x86 = (x85 & 0x7ffffff);
  int x87 = (x85 >>> 27);
  int x88 = (x52 + x87);
  int x89 = (x51 + x88);
  int x90 = (x50 + x89);
  long x91 = (x49 + (long) Integer.toUnsignedLong(((Number) (x90)).intValue()));
  int x92 = ((int) Integer.toUnsignedLong(((Number) (x91)).intValue()) & 0xfffffff);
  int x93 = (int) Integer.toUnsignedLong(((Number) ((x91 >>> 28))).intValue());
  int x94 = (x48 + x93);
  int x95 = (x47 + x94);
  int x96 = (x46 + x95);
  int x97 = (x96 & 0x7ffffff);
  int x98 = (x96 >>> 27);
  int x99 = (x45 + x98);
  int x100 = (x44 + x99);
  int x101 = (x43 + x100);
  int x102 = (x41 + x42);
  int x103 = (x40 + x102);
  int x104 = (x39 + x103);
  int x105 = (x104 & 0xfffffff);
  int x106 = (x104 >>> 28);
  int x107 = (x38 + x106);
  int x108 = (x37 + x107);
  int x109 = (x36 + x108);
  int x110 = (x109 & 0x7ffffff);
  int x111 = (x109 >>> 27);
  int x112 = (x35 + x111);
  int x113 = (x34 + x112);
  int x114 = (x33 + x113);
  long x115 = (x32 + (long) Integer.toUnsignedLong(((Number) (x114)).intValue()));
  int x116 = ((int) Integer.toUnsignedLong(((Number) (x115)).intValue()) & 0xfffffff);
  int x117 = (int) Integer.toUnsignedLong(((Number) ((x115 >>> 28))).intValue());
  int x118 = (x31 + x117);
  int x119 = (x30 + x118);
  int x120 = (x29 + x119);
  int x121 = (x120 & 0x7ffffff);
  int x122 = (x120 >>> 27);
  int x123 = (x28 + x122);
  int x124 = (x27 + x123);
  int x125 = (x26 + x124);
  long x126 = (x25 + (long) Integer.toUnsignedLong(((Number) (x125)).intValue()));
  int x127 = ((int) Integer.toUnsignedLong(((Number) (x126)).intValue()) & 0xfffffff);
  int x128 = (int) Integer.toUnsignedLong(((Number) ((x126 >>> 28))).intValue());
  int x129 = (x24 + x128);
  int x130 = (x23 + x129);
  int x131 = (x22 + x130);
  int x132 = (x131 & 0x7ffffff);
  int x133 = (x131 >>> 27);
  int x134 = (x21 + x133);
  int x135 = (x20 + x134);
  int x136 = (x19 + x135);
  int x137 = (x17 + x18);
  int x138 = (x16 + x137);
  int x139 = (x15 + x138);
  int x140 = (x139 & 0xfffffff);
  int x141 = (x139 >>> 28);
  int x142 = (x14 + x141);
  int x143 = (x13 + x142);
  int x144 = (x12 + x143);
  int x145 = (x144 & 0x7ffffff);
  int x146 = (x144 >>> 27);
  int x147 = (x11 + x146);
  int x148 = (x10 + x147);
  int x149 = (x9 + x148);
  long x150 = (x8 + (long) Integer.toUnsignedLong(((Number) (x149)).intValue()));
  int x151 = ((int) Integer.toUnsignedLong(((Number) (x150)).intValue()) & 0xfffffff);
  int x152 = (int) Integer.toUnsignedLong(((Number) ((x150 >>> 28))).intValue());
  int x153 = (x7 + x152);
  int x154 = (x6 + x153);
  int x155 = (x5 + x154);
  int x156 = (x155 & 0x7ffffff);
  int x157 = (x155 >>> 27);
  int x158 = (x4 + x157);
  int x159 = (x3 + x158);
  int x160 = (x2 + x159);
  int x161 = (x1 + x160);
  out1[0] = x70;
  out1[1] = x75;
  out1[2] = x81;
  out1[3] = x86;
  out1[4] = x92;
  out1[5] = x97;
  out1[6] = x101;
  out1[7] = x105;
  out1[8] = x110;
  out1[9] = x116;
  out1[10] = x121;
  out1[11] = x127;
  out1[12] = x132;
  out1[13] = x136;
  out1[14] = x140;
  out1[15] = x145;
  out1[16] = x151;
  out1[17] = x156;
  out1[18] = x161;
}

/**
 * The function fiat_P521_relax is the identity function converting from tight field elements to loose field elements. <p>
 * <p>
 * Postconditions: <p>
 *   out1 = arg1 <p>
 * <p>
 * Input Bounds: <p>
 *   arg1: [[0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x10000000], [0x0 ~&gt; 0x8000000], [0x0 ~&gt; 0x8000000]] <p>
 * Output Bounds: <p>
 *   out1: [[0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x30000000], [0x0 ~&gt; 0x18000000], [0x0 ~&gt; 0x18000000]] <p>
 */
public static void fiat_P521_relax(int[] out1, final int[] arg1) {
  int x1 = (arg1[0]);
  int x2 = (arg1[1]);
  int x3 = (arg1[2]);
  int x4 = (arg1[3]);
  int x5 = (arg1[4]);
  int x6 = (arg1[5]);
  int x7 = (arg1[6]);
  int x8 = (arg1[7]);
  int x9 = (arg1[8]);
  int x10 = (arg1[9]);
  int x11 = (arg1[10]);
  int x12 = (arg1[11]);
  int x13 = (arg1[12]);
  int x14 = (arg1[13]);
  int x15 = (arg1[14]);
  int x16 = (arg1[15]);
  int x17 = (arg1[16]);
  int x18 = (arg1[17]);
  int x19 = (arg1[18]);
  out1[0] = x1;
  out1[1] = x2;
  out1[2] = x3;
  out1[3] = x4;
  out1[4] = x5;
  out1[5] = x6;
  out1[6] = x7;
  out1[7] = x8;
  out1[8] = x9;
  out1[9] = x10;
  out1[10] = x11;
  out1[11] = x12;
  out1[12] = x13;
  out1[13] = x14;
  out1[14] = x15;
  out1[15] = x16;
  out1[16] = x17;
  out1[17] = x18;
  out1[18] = x19;
}

}
